Package: OutSplice
Type: Package
Title: Comparison of Splicing Events between Tumor and Normal Samples
Version: 1.11.0
Authors@R: c(person("Joseph", "Bendik", role = "aut", comment = c(ORCID = "0000-0003-0877-5639")),
    person("Sandhya", "Kalavacherla", role = "aut", comment = c(ORCID = "0000-0003-0485-9042")),
    person("Michael", "Considine", role = "aut", comment = c(ORCID = "0000-0002-8666-4857")), 
    person("Bahman", "Afsari", role = "aut", comment = c(ORCID = "0000-0001-8717-7199")),
    person("Michael F.", "Ochs", role = "aut"), 
    person("Joseph", "Califano", role = "aut", comment = c(ORCID = "0000-0002-4715-6761")), 
    person("Daria A.", "Gaykalova", role = "aut", comment = c(ORCID = "0000-0001-5037-0147")), 
    person("Elana", "Fertig", role = "aut", comment = c(ORCID = "0000-0003-3204-342X")), 
    person("Theresa", "Guo", email = "twguo@health.ucsd.edu", role = c("cre", "aut"), comment = c(ORCID = "0000-0002-1689-3275")))
Description: An easy to use tool that can compare splicing events in
    tumor and normal tissue samples using either a user generated matrix, or
    data from The Cancer Genome Atlas (TCGA). This package generates a matrix of 
    splicing outliers that are significantly over or underexpressed in tumors
    samples compared to normal denoted by chromosome location. The package also
    will calculate the splicing burden in each tumor and characterize the 
    types of splicing events that occur.
Encoding: UTF-8
License: GPL-2
Depends: R(>= 4.3)
Imports: AnnotationDbi (>= 1.60.0), GenomicRanges (>= 1.49.0),
        GenomicFeatures (>= 1.50.2), IRanges (>= 2.32.0), org.Hs.eg.db
        (>= 3.16.0), TxDb.Hsapiens.UCSC.hg19.knownGene (>= 3.2.2),
        TxDb.Hsapiens.UCSC.hg38.knownGene (>= 3.16.0), S4Vectors (>=
        0.36.0)
Suggests: BiocStyle, knitr, rmarkdown, testthat
VignetteBuilder: knitr
biocViews: AlternativeSplicing, DifferentialExpression,
        DifferentialSplicing, GeneExpression, RNASeq, Software,
        VariantAnnotation
BugReports: https://github.com/GuoLabUCSD/OutSplice/issues
URL: https://github.com/GuoLabUCSD/OutSplice
RoxygenNote: 7.2.3
git_url: https://git.bioconductor.org/packages/OutSplice
git_branch: devel
git_last_commit: 14e6259
git_last_commit_date: 2025-10-29
Repository: Bioconductor 3.23
Date/Publication: 2025-11-04
NeedsCompilation: no
Packaged: 2025-11-05 00:05:46 UTC; biocbuild
Author: Joseph Bendik [aut] (ORCID: <https://orcid.org/0000-0003-0877-5639>),
  Sandhya Kalavacherla [aut] (ORCID:
    <https://orcid.org/0000-0003-0485-9042>),
  Michael Considine [aut] (ORCID:
    <https://orcid.org/0000-0002-8666-4857>),
  Bahman Afsari [aut] (ORCID: <https://orcid.org/0000-0001-8717-7199>),
  Michael F. Ochs [aut],
  Joseph Califano [aut] (ORCID: <https://orcid.org/0000-0002-4715-6761>),
  Daria A. Gaykalova [aut] (ORCID:
    <https://orcid.org/0000-0001-5037-0147>),
  Elana Fertig [aut] (ORCID: <https://orcid.org/0000-0003-3204-342X>),
  Theresa Guo [cre, aut] (ORCID: <https://orcid.org/0000-0002-1689-3275>)
Maintainer: Theresa Guo <twguo@health.ucsd.edu>
